Cryptographic Module Validation Program | CSRC
Author: Computer Security Division, Information Technology Laboratory, National Institute of Standards and Technology, U.S. Department of Commerce
Description: The MIP list contains cryptographic modules on which the CMVP is actively working. For a module to transition from Review Pending to In Review, the lab must first pay the NIST Cost Recovery fee, and then the report will be assigned as resources become...
Date: 2016-10-11

You are viewing this page in an unauthorized frame window.

This is a potential security issue, you are being redirected to https://csrc.nist.gov.

An official website of the United States government

Official websites use .gov
A .gov website belongs to an official government organization in the United States.

Secure .gov websites use HTTPS
A lock () or https:// means you've safely connected to the .gov website. Share sensitive information only on official, secure websites.

# Cryptographic Module Validation Program CMVP

### Modules In Process List

The MIP list contains cryptographic modules on which the CMVP is actively working. For a module to transition from Review Pending to In Review, the lab must first pay the NIST Cost Recovery fee, and then the report will be assigned as resources become available. The validation process is a joint effort between the CMVP, the laboratory and the vendor and therefore, for any given module, the action to respond could reside with the CMVP, the lab or the vendor. This list does not provide granularity into which entity has the action. If you would like more information for a specific cryptographic module or its schedule, please contact the vendor.

Last Updated: 12/18/2021

Module Name | Vendor Name | Standard | Status
--- | --- | --- | ---
Thunder Series TH3040S, TH5440S, TH5840S and TH7440S-11 | A10 Networks, Inc. View Contacts | FIPS 140-2 | Coordination
ADVA 10TCE-PCN-16GU+AES100G-F encryption module | ADVA Optical Networking SE View Contacts | FIPS 140-2 | Review Pending
AMD Ryzen PRO 4000 Series PSP Cryptographic CoProcessor | Advanced Micro Devices View Contacts | FIPS 140-3 | Review Pending
AMD Ryzen PRO 5000 Series PSP Cryptographic CoProcessor | Advanced Micro Devices View Contacts | FIPS 140-3 | Review Pending
AT-x220, AT-x320, AT-x950 Secure Management Module | Allied Telesis View Contacts | FIPS 140-2 | Review Pending
AWS Key Management Service HSM | Amazon Web Services, Inc. View Contacts | FIPS 140-2 | Review Pending
AWS Key Management Service HSM | Amazon Web Services, Inc. View Contacts | FIPS 140-2 | Coordination
Apacer TCG SSD SV240 Series | Apacer Technology Inc. View Contacts | FIPS 140-2 | Review Pending
Apple corecrypto Module v11.1 [Apple silicon, User, Software] | Apple View Contacts | FIPS 140-3 | In Review
Apple corecrypto Module v11.1 [Apple silicon, Kernel, Software] | Apple Inc. View Contacts | FIPS 140-3 | In Review
Apple corecrypto Module v11.1 [Intel, Kernel, Software] | Apple Inc. View Contacts | FIPS 140-3 | In Review
Apple corecrypto Module v11.1 [Intel, User, Software] | Apple Inc. View Contacts | FIPS 140-3 | In Review
Aegis Secure Key 3Z and Aegis Secure Key 3NX Cryptographic Module | Apricorn View Contacts | FIPS 140-2 | Review Pending
CHR Cryptographic Module | Atos View Contacts | FIPS 140-2 | Coordination
CRATON2/SECTON embedded V2X HSM | Autotalks Ltd. View Contacts | FIPS 140-2 | Coordination
Aviat Networks Eclipse Cryptographic Module | Aviat Networks, Inc. View Contacts | FIPS 140-2 | Review Pending
Barracuda KTINA FIPS Crypto Module | Barracuda Networks View Contacts | FIPS 140-2 | Review Pending
Alaris™ PC Unit Model 8015 | BD View Contacts | FIPS 140-2 | Review Pending
Cryptographic Server HSM | Beijing Lianshi Networks Technology Co.,Ltd. View Contacts | FIPS 140-2 | Coordination
Security Builder® FIPS Module | BlackBerry Limited View Contacts | FIPS 140-2 | Review Pending
PTP 700 Point to Point Wireless Ethernet Bridge | Cambium Networks, Ltd. View Contacts | FIPS 140-2 | Review Pending
Ubuntu 20.04 Kernel Crypto API Cryptographic Module | Canonical Ltd. View Contacts | FIPS 140-2 | Review Pending
Ubuntu 20.04 OpenSSL Cryptographic Module | Canonical Ltd. View Contacts | FIPS 140-2 | Review Pending
LenelS2 OnGuard Access Control Cryptographic Module | Carrier Fire & Security Americas Corporation View Contacts | FIPS 140-2 | Review Pending
Check Point Cryptographic Library | Check Point Software Technologies Ltd. View Contacts | FIPS 140-2 | Coordination
Radio Internet-Protocol Communications Module Z (RIC-Mz) | Christine Wireless, Inc. View Contacts | FIPS 140-2 | Coordination
Tactical Key Management Device (TKMD) | Christine Wireless, Inc. View Contacts | FIPS 140-2 | Coordination
Cisco 8800 Series Routers | Cisco Systems, Inc. View Contacts | FIPS 140-2 | Coordination
Cisco Aironet 1562e/i/d/ps, 2802e/i, 3802e/i/p, 4800 and IW6300H-AC/DC/DCW Wireless LAN Access Points, Version IOS-XE 17.3 | Cisco Systems, Inc. View Contacts | FIPS 140-2 | Coordination
Cisco Catalyst 9115AXI/AXE, 9120AXI/AXE/AXP, 9130AXI/AXE and 9105AXI/AXW Wireless LAN Access Points | Cisco Systems, Inc. View Contacts | FIPS 140-2 | Coordination
R650-US Access Point, R650-WW Access Point, R750 Access Point, R850 Access Point, T750SE Access Point, T750 Access Point, and T750-WW Access Point | CommScope Technologies LLC View Contacts | FIPS 140-2 | Coordination
QASM Cryptographic Module | Crypto4A Technologies Inc. View Contacts | FIPS 140-2 | In Review
Vocality RoIP and DTECH M3-SE Multi-Function Gateway Appliances | Cubic Corporation View Contacts | FIPS 140-2 | Coordination
CyberCogs Hardware Security Module | CyberCogs, Inc. View Contacts | FIPS 140-2 | Review Pending
RSA BSAFE(R) Crypto Module | Dell Inc, BSAFE Product Team View Contacts | FIPS 140-2 | Coordination
RSA BSAFE(R) Crypto-C Micro Edition | Dell Inc, BSAFE Product Team View Contacts | FIPS 140-2 | Coordination
DINAMO CD, XP, and ST Hardware Security Modules | DINAMO Networks, Inc. View Contacts | FIPS 140-2 | Coordination
ECI TM200EN Encryption Module | ECI Telecom Ltd. View Contacts | FIPS 140-2 | Coordination
Eclypses Cryptographic Library | Eclypses, Inc. View Contacts | FIPS 140-3 | Review Pending
MiniHSM & MiniHSM for nShield Edge F2 | Entrust, Inc. View Contacts | FIPS 140-2 | Review Pending
MiniHSM & MiniHSM for nShield Edge F3 | Entrust, Inc. View Contacts | FIPS 140-2 | Review Pending
nShield F2 500+ & nShield F2 1500+ & nShield F2 6000+ | Entrust, Inc. View Contacts | FIPS 140-2 | Review Pending
nShield F3 10+ 500+ 6000+ & nShield F3 500+ 1500+ 6000+ for nShield Connect+ and Connect CLX | Entrust, Inc. View Contacts | FIPS 140-2 | Review Pending
nShield F3 10+ 500+ 6000+ & nShield F3 500+ 1500+ 6000+ for nShield Connect+ and Connect CLX | Entrust, Inc. View Contacts | FIPS 140-2 | Review Pending
nShield Solo XC F2 | Entrust, Inc. View Contacts | FIPS 140-2 | Review Pending
nShield Solo XC F3 & nShield Solo XC F3 for nShield Connect XC and for nShield HSMi | Entrust, Inc. View Contacts | FIPS 140-2 | Review Pending
nShield Solo XC F3 & nShield Solo XC F3 for nShield Connect XC and for nShield HSMi | Entrust, Inc. View Contacts | FIPS 140-2 | Review Pending
Extreme Networks SLX 9540 and SLX 9740 Switches | Extreme Networks, Inc. View Contacts | FIPS 140-2 | Review Pending
Extreme® MLXe® Series Ethernet Routers | Extreme Networks, Inc. View Contacts | FIPS 140-2 | Coordination
Extreme® NetIron® CER 2000 Series Ethernet Routers | Extreme Networks, Inc. View Contacts | FIPS 140-2 | Coordination
Cryptographic Module for BIG-IP (R) | F5 Networks, Inc. View Contacts | FIPS 140-2 | Review Pending
Cryptographic Module for BIG-IP (R) | F5 Networks, Inc. View Contacts | FIPS 140-2 | Review Pending
F5(R) Device Cryptographic Module | F5 Networks, Inc. View Contacts | FIPS 140-2 | Review Pending
F5(R) vCMP Cryptographic Module | F5 Networks, Inc. View Contacts | FIPS 140-2 | Review Pending
Fortanix SDKMS Appliance | Fortanix, Inc. View Contacts | FIPS 140-2 | Coordination
FortiAnalyzer 6.2 | Fortinet, Inc. View Contacts | FIPS 140-2 | Review Pending
FortiManager 6.2 | Fortinet, Inc. View Contacts | FIPS 140-2 | Review Pending
FortiSandbox-1000F/2000E/3000E | Fortinet, Inc. View Contacts | FIPS 140-2 | Coordination
Inline Crypto Engine (ICE) | Google, LLC View Contacts | FIPS 140-2 | Review Pending
Integrated Management Complex (IMC) and B227 True Random Number Generator (TRNG) Firmware-Hybrid Cryptographic Module | Google, LLC View Contacts | FIPS 140-2 | Review Pending
Look-aside Cryptography and Compression Engine (LCE) | Google, LLC View Contacts | FIPS 140-2 | Review Pending
Non-Volatile Memory express (NVMe) Data Path Security Cluster (DPSC) Module | Google, LLC View Contacts | FIPS 140-2 | Review Pending
BoringCrypto | Google, LLC. View Contacts | FIPS 140-2 | Review Pending
BoringCrypto Android | Google, LLC. View Contacts | FIPS 140-2 | Coordination
BoringCrypto SoC | Google, LLC. View Contacts | FIPS 140-2 | Review Pending
Titan-D Chip | Google, LLC. View Contacts | FIPS 140-2 | Review Pending
Black Lantern Cryptographic Module | Guardtime Federal View Contacts | FIPS 140-2 | Review Pending
Hitachi Virtual Storage Platform (VSP) Encryption Board for NVMe | Hitachi, Ltd. View Contacts | FIPS 140-2 | Review Pending
Hitachi Virtual Storage Platform (VSP) Encryption Module | Hitachi, Ltd. View Contacts | FIPS 140-2 | Review Pending
HSSD_V6 Series | Huawei Technologies CO., Ltd. View Contacts | FIPS 140-2 | Review Pending
Huawei EulerOS 2.0 OpenSSH Client Cryptographic Module | Huawei Technologies CO., Ltd. View Contacts | FIPS 140-2 | Review Pending
Huawei EulerOS 2.0 OpenSSH Server Cryptographic Module | Huawei Technologies CO., Ltd. View Contacts | FIPS 140-2 | Review Pending
Huawei EulerOS 2.0 OpenSSL Cryptographic Module | Huawei Technologies CO., Ltd. View Contacts | FIPS 140-2 | Review Pending
Hub Security Cryptographic Module | Hub Security LTD View Contacts | FIPS 140-2 | Coordination
Hughes HT2010 Satellite Terminal | Hughes Network Systems, LLC View Contacts | FIPS 140-2 | Review Pending
Hughes HT2300, HT2500, HT2550, HT2650 Satellite Terminals | Hughes Network Systems, LLC View Contacts | FIPS 140-2 | Review Pending
Hughes IPsec IP Gateway Server | Hughes Network Systems, LLC View Contacts | FIPS 140-2 | Review Pending
HyTrust KeyControl Cryptographic Module | HyTrust, Inc. View Contacts | FIPS 140-2 | Coordination
ICU Medical CE3.0 OpenSSL Cryptographic Module | ICU Medical, Inc. View Contacts | FIPS 140-2 | Review Pending
SLS37CSAUS V2X | Infineon Technologies AG View Contacts | FIPS 140-2 | Review Pending
Trusted Platform Module 2.0 SLB 9672 | Infineon Technologies AG View Contacts | FIPS 140-2 | Coordination
Infinera Groove? G30 DCI Platform | Infinera Corporation View Contacts | FIPS 140-2 | Coordination
Cryptographic Module for Intel(R) Converged Security and Manageability Engine (CSME) | Intel Corporation View Contacts | FIPS 140-2 | Coordination
Cryptographic Module for Intel® Platforms' Security Engine Chipset | Intel Corporation View Contacts | FIPS 140-2 | Coordination
Intel(R) Converged Security and Manageability Engine (CSME) Crypto Module for Tiger Point PCH, Mule Creek Canyon PCH, and Rocket Lake PCH | Intel Corporation View Contacts | FIPS 140-2 | Coordination
IQVIA Java Crypto Module | IQVIA View Contacts | FIPS 140-2 | Coordination
Juniper Networks ACX5448-M Router | Juniper Networks, Inc View Contacts | FIPS 140-2 | Coordination
Juniper Networks EX4650, QFX5120 and QFX5210 Ethernet Switches | Juniper Networks, Inc View Contacts | FIPS 140-2 | Coordination
Juniper Networks SRX345, SRX345-DUAL-AC, SRX380 and SRX1500 Services Gateway | Juniper Networks, Inc View Contacts | FIPS 140-2 | Coordination
Juniper Kernel Crypto Cryptographic Module | Juniper Networks, Inc. View Contacts | FIPS 140-2 | Coordination
Juniper OpenSSL Cryptographic Module | Juniper Networks, Inc. View Contacts | FIPS 140-2 | Coordination
Secure Cryptographic Module (SCM) | JVCKENWOOD Corporation View Contacts | FIPS 140-2 | Review Pending
Defender HDD 300 | Kanguru Solutions View Contacts | FIPS 140-2 | Coordination
KIOXIA TCG Enterprise SSC Crypto Sub-Chip TC58NC1040GTB | KIOXIA Corporation View Contacts | FIPS 140-3 | In Review
KIOXIA TCG Enterprise SSC Crypto Sub-Chip TC58NC1132GTC | KIOXIA Corporation View Contacts | FIPS 140-3 | In Review
KIOXIA TCG OPAL SSC Crypto Sub-Chip TC58NC1132GTC | KIOXIA Corporation View Contacts | FIPS 140-3 | In Review
Harris AES Load Module | L3Harris Technologies, Inc. View Contacts | FIPS 140-2 | Coordination
RF-7800W Broadband Ethernet Radio | L3Harris Technologies, Inc. View Contacts | FIPS 140-2 | Coordination
Summit Linux FIPS Core Crypto Module | Laird Connectivity View Contacts | FIPS 140-2 | Review Pending
BC-FNA (Bouncy Castle FIPS .NET API) | Legion of the Bouncy Castle Inc. View Contacts | FIPS 140-2 | Review Pending
LogRhythm 7.4.8 Console | LogRhythm View Contacts | FIPS 140-2 | Review Pending
LogRhythm 7.4.8 Data Processor | LogRhythm View Contacts | FIPS 140-2 | Review Pending
LogRhythm 7.4.8 Platform Manager | LogRhythm View Contacts | FIPS 140-2 | Review Pending
LogRhythm 7.4.8 System Monitor Agent | LogRhythm View Contacts | FIPS 140-2 | Review Pending
LogRhythm 7.4.8 AI Engine Server | LogRhythm Inc. View Contacts | FIPS 140-2 | Review Pending
Macronix ArmorFlash MX78 series | Macronix International Co., Ltd. View Contacts | FIPS 140-2 | Coordination
Marvell LS2 HSM Family | Marvell Semiconductor, Inc. View Contacts | FIPS 140-3 | Review Pending
NITROXIII CNN35XX-NFBE HSM Family | Marvell Semiconductor, Inc. View Contacts | FIPS 140-2 | Review Pending
NITROXIII CNN35XX-NFBE HSM Family | Marvell Semiconductor, Inc. View Contacts | FIPS 140-3 | In Review
McAfee Core Cryptographic Module (kernel) | McAfee, LLC View Contacts | FIPS 140-2 | Review Pending
McAfee Core Cryptographic Module (user) | McAfee, LLC View Contacts | FIPS 140-2 | Review Pending
Microchip Trust Anchor TA100 | Microchip Technology Inc View Contacts | FIPS 140-2 | Review Pending
CBL-Mariner Kernel Crypto API | Microsoft Corporation View Contacts | FIPS 140-2 | Review Pending
CBL-Mariner OpenSSL Cryptographic Module | Microsoft Corporation View Contacts | FIPS 140-2 | Review Pending
FIPS AP43 | Mist Systems View Contacts | FIPS 140-2 | Review Pending
Command Encryption Module | Mitsubishi Space Software Co., Ltd. View Contacts | FIPS 140-2 | Coordination
Mocana Cryptographic Loadable Kernel Module | Mocana Corporation View Contacts | FIPS 140-2 | Coordination
Mocana Cryptographic Suite B Module | Mocana Corporation View Contacts | FIPS 140-2 | Coordination
Mocana Cryptographic Suite B Module | Mocana Corporation View Contacts | FIPS 140-2 | Coordination
Monaco Communication Cryptographic Module 1.0 | Monaco Enterprises Inc. View Contacts | FIPS 140-2 | Review Pending
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 2 | Motorola Solutions, Inc. View Contacts | FIPS 140-2 | Coordination
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 3 | Motorola Solutions, Inc. View Contacts | FIPS 140-2 | Coordination
KMF/Wave/Traffic CryptR | Motorola Solutions, Inc. View Contacts | FIPS 140-2 | Review Pending
Motorola Solutions Cryptographic Firmware Module | Motorola Solutions, Inc. View Contacts | FIPS 140-2 | Coordination
Motorola Solutions Cryptographic Software Module | Motorola Solutions, Inc. View Contacts | FIPS 140-2 | Coordination
Voice Processing Module Cryptographic Module (VPMCM) / Telephone Media Gateway Cryptographic Module (TMGCM) | Motorola Solutions, Inc. View Contacts | FIPS 140-2 | Review Pending
NEC Storage Encryption Board for NVMe | NEC Corporation View Contacts | FIPS 140-2 | Review Pending
NetApp CryptoMod | NetApp, Inc. View Contacts | FIPS 140-2 | Coordination
NETSCOUT FIPS Object Module | NETSCOUT Systems, Inc. View Contacts | FIPS 140-2 | Coordination
7705 SAR-OS SAR-18/8/X/Ax/Wx/W/H/Hc Control Plane Cryptographic Module (SARCPCM) | Nokia Corporation View Contacts | FIPS 140-2 | Coordination
7705 SAR-OS SAR-18/8/X/Ax/Wx/W/H/Hc Data Plane Cryptographic Module (SARDCM) | Nokia Corporation View Contacts | FIPS 140-2 | Coordination
7705 SAR-OS SAR-A/M Cryptographic Module (SARCM) | Nokia Corporation View Contacts | FIPS 140-2 | Coordination
Nokia 1830 Photonic Service Switch (PSS) | Nokia Corporation View Contacts | FIPS 140-2 | Coordination
SR-OS Cryptographic Module | Nokia Corporation View Contacts | FIPS 140-2 | Coordination
Nutanix Cryptographic Module for OpenSSH Client | Nutanix, Inc. View Contacts | FIPS 140-2 | Review Pending
Nutanix Cryptographic Module for OpenSSH Server | Nutanix, Inc. View Contacts | FIPS 140-2 | Review Pending
Nutanix Cryptographic Module for OpenSSL | Nutanix, Inc. View Contacts | FIPS 140-2 | Review Pending
NPCT7xx TPM 2.0 rev 1.59 | Nuvoton Technology Corporation View Contacts | FIPS 140-2 | Review Pending
Nuvoton Cryptographic Library 2.0 | Nuvoton Technology Corporation View Contacts | FIPS 140-3 | In Review
i.MX 8X SECO HSMv2 | NXP Semiconductors View Contacts | FIPS 140-2 | In Review
Oracle Linux 7 Libreswan Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Review Pending
Oracle Linux 7 NSS Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | In Review
Oracle Linux 7 OpenSSH Client Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Review Pending
Oracle Linux 7 OpenSSH Server Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Review Pending
Oracle Linux 7 OpenSSL Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | In Review
Oracle Linux 7 Unbreakable Enterprise Kernel (UEK6) Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Coordination
Oracle Linux 8 GnuTLS Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Review Pending
Oracle Linux 8 libgcrypt Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Review Pending
Oracle Linux 8 NSS Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Review Pending
Oracle Linux 8 OpenSSL Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Review Pending
Oracle Linux 8 Unbreakable Enterprise Kernel (UEK6) Cryptographic Module | Oracle Corporation View Contacts | FIPS 140-2 | Review Pending
Oracle Solaris Userland Cryptographic Framework | Oracle Corporation View Contacts | FIPS 140-2 | Coordination
OSNEXUS Crypto Library | OSNEXUS Corporation View Contacts | FIPS 140-2 | Coordination
Instant-On Networks (ION) devices ION 1000, ION 2000, ION 3000, ION 7000, and ION 9000 | Palo Alto Networks, Inc. View Contacts | FIPS 140-2 | Coordination
Cryptographic Module for DSC2-2Q200 | Pensando Systems, Inc View Contacts | FIPS 140-2 | Review Pending
X4i Hardware Security Module (HSM) | Pitney Bowes, Inc. View Contacts | FIPS 140-2 | Review Pending
Qualcomm(R) Crypto Engine Core | Qualcomm Technologies, Inc. View Contacts | FIPS 140-2 | Review Pending
Qualcomm(R) Secure Processing Unit | Qualcomm Technologies, Inc. View Contacts | FIPS 140-2 | Review Pending
Qualcomm(R) Trusted Execution Environment (TEE) Software Cryptographic Library | Qualcomm Technologies, Inc. View Contacts | FIPS 140-2 | Review Pending
Qumulo Secure | Qumulo, Inc. View Contacts | FIPS 140-2 | Review Pending
CryptoManager Root of Trust (CMRT) | Rambus Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 GnuTLS Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 GnuTLS Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 Kernel Crypto API Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 Kernel Crypto API Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 Kernel Crypto API Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | In Review
Red Hat Enterprise Linux 8 libgcrypt Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 libgcrypt Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 NSS Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 NSS Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 OpenSSL Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 OpenSSL Cryptographic Module | Red Hat(R), Inc. View Contacts | FIPS 140-2 | Review Pending
SAAB Encrypted Automatic Identification System Cryptographic Module (EAISCM) | Saab AB (publ) TransponderTech (SAAB) View Contacts | FIPS 140-2 | Coordination
Samsung NVMe TCG Opal SSC SEDs PM1733 Series | Samsung Electronics Co., Ltd. View Contacts | FIPS 140-2 | Coordination
Samsung NVMe TCG Opal SSC SEDs PM1733/PM1735 Series | Samsung Electronics Co., Ltd. View Contacts | FIPS 140-2 | Review Pending
Samsung NVMe TCG Opal SSC SEDs PM9A3 Series | Samsung Electronics Co., Ltd. View Contacts | FIPS 140-3 | Review Pending
Samsung SCrypto Cryptographic Module | Samsung Electronics Co., Ltd. View Contacts | FIPS 140-2 | In Review
SecHSM V2-1 (AC) and SecHSM V2-1 (DC) | Sansec Technology Co., Ltd. View Contacts | FIPS 140-2 | Coordination
Seagate Secure(R) TCG Enterprise SSC Self-Encrypting Drives FIPS 140 Module | Seagate Technology LLC View Contacts | FIPS 140-2 | Review Pending
Seagate Secure(R) Self-Encrypting Drive | Seagate Technology, LLC View Contacts | FIPS 140-3 | Review Pending
SecureData Engine | SecureAge Technology View Contacts | FIPS 140-2 | Review Pending
AxioCrypto-M235x | Security Platform Inc. View Contacts | FIPS 140-2 | Review Pending
CN Series Encryptors | Senetas Corporation Ltd., distributed by Thales SA (SafeNet) View Contacts | FIPS 140-2 | Review Pending
CN6000 Series Encryptors | Senetas Corporation Ltd., distributed by Thales SA (SafeNet) View Contacts | FIPS 140-2 | Review Pending
GM01 | Shanghai Muge Technology Co., Ltd View Contacts | FIPS 140-2 | Review Pending
SX-590-1402 | silex technology, Inc. View Contacts | FIPS 140-2 | Coordination
Silver Peak ECOS Cryptographic Library | Silver Peak Systems Inc. View Contacts | FIPS 140-2 | Coordination
Silver Peak Unity EdgeConnect EC-XS-FIPS, EC-M-P-FIPS, EC-XL-P-FIPS and EC-XL-P-NM-FIPS | Silver Peak Systems, Inc. View Contacts | FIPS 140-2 | Coordination
SK hynix PE8010 and PE8030 NVMe Opal SEDs | SK hynix Inc. View Contacts | FIPS 140-2 | Review Pending
SK hynix PE8110 M.2 22110D NVMe TCG Opal SSC SED | SK hynix Inc. View Contacts | FIPS 140-2 | Review Pending
SK hynix PE8111 E1.L NVMe TCG Opal SSC SED | SK hynix Inc. View Contacts | FIPS 140-2 | Review Pending
SonicWall Capture Security Appliance (CSa) 1000 | SonicWall View Contacts | FIPS 140-2 | Review Pending
SonicWall Network Security Virtual Appliances | SonicWall, Inc. View Contacts | FIPS 140-2 | Coordination
SonicWALL NSsp 14700 and NSsp 15700 | SonicWall, Inc. View Contacts | FIPS 140-2 | Coordination
SonicWALL SMA Series v12.4 SMA 6210, SMA 7210, SMA 7200 | SonicWall, Inc. View Contacts | FIPS 140-2 | Review Pending
SonicWALL SMA Series v12.4 SMA 8200v | SonicWall, Inc. View Contacts | FIPS 140-2 | Review Pending
SonicWALL TZ270, TZ270W, TZ370, TZ370W, TZ470, TZ470W, TZ570, TZ570W, TZ570P, TZ670, NSa 2700 and NSa 3700 | SonicWall, Inc. View Contacts | FIPS 140-2 | Coordination
Trusted Platform Module ST33TPHF2XSPI [A], ST33TPHF2XI2C [B], ST33GTPMASPI [C], ST33GTPMAI2C [D], ST33GTPMISPI [E] & ST33GTPMII2C [F] | STMicroelectronics View Contacts | FIPS 140-2 | Review Pending
Symantec Content Analysis Virtual Appliance | Symantec, A Division of Broadcom View Contacts | FIPS 140-2 | Review Pending
Symantec Integrated Secure Gateway | Symantec, A Division of Broadcom View Contacts | FIPS 140-2 | Review Pending
TruLink Control Logic Module CL6792-M1 | Telephonics Corporation View Contacts | FIPS 140-2 | Review Pending
TruLink Control Logic Module CL6882-M1 | Telephonics Corporation View Contacts | FIPS 140-2 | Review Pending
Tera2 PCoIP Zero Client Processors | Teradici Corporation View Contacts | FIPS 140-2 | Review Pending
IDPrime 3930 FIDO | Thales View Contacts | FIPS 140-2 | Review Pending
ProtectServer Internal Express 2 (PSI-E2) | Thales View Contacts | FIPS 140-2 | Coordination
ProtectServer PCIe HSM 3 | Thales View Contacts | FIPS 140-2 | Coordination
Thales CipherTrust Manager Core Security Module | Thales View Contacts | FIPS 140-2 | Review Pending
Thales Luna K7 Cryptographic Module | Thales View Contacts | FIPS 140-3 | Review Pending
OpenSSL FIPS Provider | The OpenSSL Project View Contacts | FIPS 140-2 | Review Pending
Titaniam Core Engine | Titaniam, Inc. View Contacts | FIPS 140-2 | Review Pending
Toshiba Secure TCG Opal SSC Self-Encrypting Drive Series MG09ACP18TA and MG09ACP16TA | Toshiba Electronic Devices & Storage Corporation View Contacts | FIPS 140-3 | Review Pending
Toshiba Secure TCG Opal SSC Self-Encrypting Drive Series MG09SCP18TA and MG09SCP16TA | Toshiba Electronic Devices & Storage Corporation View Contacts | FIPS 140-3 | Review Pending
TW-900/950 TSM Shadow and TW-870/875 TSM Ghost | TrellisWare Technologies, Inc. View Contacts | FIPS 140-2 | Coordination
AN/GRC-262 | Ultra Electronics - TCS View Contacts | FIPS 140-2 | Review Pending
u.trust Anchor | Utimaco IS GmbH View Contacts | FIPS 140-2 | Coordination
RAD X-1040 AES-256 | Vcinity, Inc. View Contacts | FIPS 140-2 | Coordination
Versa Networks Branch | Versa Networks, Inc. View Contacts | FIPS 140-2 | Review Pending
Versa Networks Controller | Versa Networks, Inc. View Contacts | FIPS 140-2 | Review Pending
Virtru JavaScript Cryptographic Library | Virtru Corporation View Contacts | FIPS 140-2 | Coordination
VMware’s Linux Cryptographic Module | VMware, Inc. View Contacts | FIPS 140-2 | Review Pending
VMware's ESXboot Cryptographic Module | VMware, Inc. View Contacts | FIPS 140-3 | Review Pending
VMware's VPN Crypto Module | VMware, Inc. View Contacts | FIPS 140-2 | Review Pending
Vocera Cryptographic Module | Vocera Communications, Inc. View Contacts | FIPS 140-2 | Review Pending
WatchKey ProX USB Token Cryptographic Module | WatchData Technologies Pte Ltd View Contacts | FIPS 140-2 | Coordination
Ultrastar® DC HC550 and DC HC650 TCG Opal Self-Encrypting Drive | Western Digital Corporation View Contacts | FIPS 140-2 | Review Pending
Ultrastar® DC SN540 NVMe™ PCIe 3.0 Self Encrypting Drive | Western Digital Corporation View Contacts | FIPS 140-2 | In Review
Ultrastar® DC SN640 NVMe™ PCIe 3.0 Self-Encrypting Drive | Western Digital Technologies, Inc. View Contacts | FIPS 140-2 | Review Pending
Ultrastar® DC SN840 NVMe™ PCIe 3.0 Self Encrypting Drive | Western Digital Technologies, Inc. View Contacts | FIPS 140-2 | In Review
SecureDoc® Cryptographic Engine for macOS/Linux | WinMagic Corp View Contacts | FIPS 140-2 | Review Pending
SecureDoc® Cryptographic Engine for Windows | WinMagic Corp View Contacts | FIPS 140-2 | Review Pending
KeyVault Hardware Security Module (kvHSM) | WiSECURE Technologies View Contacts | FIPS 140-2 | Review Pending
VaultIC™ 405 1.2.6 | WISeKey Semiconductors View Contacts | FIPS 140-2 | Review Pending
VaultIC™ 405 1.2.6 | WISeKey Semiconductors View Contacts | FIPS 140-2 | Review Pending
ZBR-88W8887-WLAN | Zebra Technologies Corporation View Contacts | FIPS 140-2 | Review Pending
Zebra DCS Cryptographic Library | Zebra Technologies Corporation View Contacts | FIPS 140-3 | Review Pending
DHSSL Cryptographic Module | Zhejiang Dahua Technology Co., Ltd. View Contacts | FIPS 140-2 | Coordination
Displayed | 236
Not Displayed | 34
Total | 270

Created October 11, 2016, Updated December 14, 2021